@@ -8,10 +8,11 @@ import gtk
 from glib import GError
 import gobject
 import time
+import os
 from gameclock.game import Game
 import gameclock.clock
 from gameclock import __version__, __license__, __copyright__
-from pkg_resources import resource_filename, Requirement
+from pkg_resources import resource_filename, Requirement, DistributionNotFound
 
 class GameclockUI:
     """this class handles most of the UI and turned-based logic
@@ -27,8 +28,8 @@ class GameclockUI:
     fullscreen = False
     # the game this UI references
     game = None
-    sec_loop_timeout = 200 # in ms, clocks are incremented every time this timeout ends
-    ms_loop_timeout = 50 # in ms, the same as above, in milisecond mode
+    sec_loop_timeout = 500 # in ms, clocks are incremented every time this timeout ends
+    ms_loop_timeout = 100 # in ms, the same as above, in milisecond mode
     menubar = None # used in the fullscreen toggle
 
     class ClockUI:
@@ -155,10 +156,10 @@ class GameclockUI:
             dialog.destroy()
             if response_id == gtk.RESPONSE_ACCEPT:
                 if self.ms_ctrl.get_active():
-                    self.ui.maybe_print("running in miliseconds")
+                    self.ui.debug("running in miliseconds")
                     self.ui.loop_timeout = self.ui.ms_loop_timeout
                 else:
-                    self.ui.maybe_print("running in seconds")
+                    self.ui.debug("running in seconds")
                     self.ui.loop_timeout = self.ui.sec_loop_timeout
 
                 hours = self.hours_val.get_value()
@@ -169,7 +170,7 @@ class GameclockUI:
                 for type, button in self.type_buttons.items():
                     if button.get_active():
                         game = Game(eval("gameclock.clock.%sClock" % type), self.count_players(), default_time, self.ms_ctrl.get_active(), self.get_fisher())
-                        self.ui.maybe_print("created %s game" % type)
+                        self.ui.debug("created %s game" % type)
 
                 self.ui.game = game
                 self.ui.setup_clocks(int(self.players_val.get_value()))
@@ -212,7 +213,6 @@ class GameclockUI:
             window.connect("delete_event", lambda a, b: False)
             window.connect("destroy", lambda a: window.destroy)
             window.connect('response', self.handle_new_dialog)
-            window.show()
             controls = gtk.HBox(False, 0)
             controls.show()
             window.vbox.pack_start(controls)
@@ -331,6 +331,7 @@ class GameclockUI:
             button.show()
             right_controls.pack_start(button, False, False, 0)
             controls.pack_start(right_controls)
+            window.show()
             return window
 
         def shortcuts_dialog(self, action = None):
@@ -340,7 +341,7 @@ class GameclockUI:
             # little help
             label = gtk.Label("""<b>shift</b> and <b>space</b> keys end turns
 <b>control-q</b> quits
-<b>control-n</b> starts a new fgame
+<b>control-n</b> starts a new game
 <b>control-f</b> enables fullscreen mode
 <b>control-p, F5-F8</b> pause the game
 
@@ -361,7 +362,7 @@ much right right side if it *is* present.
             dialog.set_version(__version__)
             dialog.set_copyright(__copyright__)
             dialog.set_license(__license__)
-            dialog.set_comments("A simple game clock to be used for Chess or any board game. Written by Antoine Beaupré <anarcat@koumbit.org>")
+            dialog.set_comments("A simple game clock to be used for Chess or any board game.")
             dialog.set_website("https://redmine.koumbit.net/projects/gameclock")
             dialog.connect("response", lambda a, b: dialog.destroy())
             dialog.show()
@@ -376,14 +377,16 @@ much right right side if it *is* present.
             icon = resource_filename(Requirement.parse("gameclock"), 'gameclock.svg')
             gtk.window_set_default_icon_from_file(icon)
         except GError as e:
-            self.maybe_print("could not find icon: %s" % e)
-            try:
-                # this is necessary because, for some reason, the code
-                # above doesn't look in the data_files defined in setup.py
-                gtk.window_set_default_icon_from_file("/usr/share/pixmaps/gameclock.svg")
-            except GError as e:
-                self.maybe_print("could not find icon: %s" % e)
-                pass
+            # misconfigured, ignore
+            self.debug("could not find icon: %s" % e)
+        except DistributionNotFound:
+            # not installed system-wide, ignore
+            pass
+        finally:
+            # last resort, try the FHS and source directories
+            for icon in ["/usr/share/pixmaps/gameclock.svg", os.path.dirname(__file__) + "/../gameclock.svg"]:
+                if os.path.exists(icon):
+                    gtk.window_set_default_icon_from_file(icon)
 
         # create a new window
         self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
@@ -421,14 +424,6 @@ much right right side if it *is* present.
         self.clock_table.show()
         vlayout.pack_start(self.clock_table, True, True, 0)
 
-        self.status_bar = gtk.Statusbar()
-        vlayout.pack_start(self.status_bar, False, False, 0)
-        self.status_bar.set_has_resize_grip(False);
-        # make sure the text is visible
-        label = self.status_bar.get_message_area().get_children()[0]
-        label.modify_fg(gtk.STATE_NORMAL, gtk.gdk.Color('white'))
-        self.status_bar.show()
-
         vlayout.show()
 
         if self.fullscreen:
@@ -475,7 +470,7 @@ much right right side if it *is* present.
         rows = (players - 1)/ cols + 1
         self.clock_table.resize(rows, cols)
         self.refresh()
-        self.maybe_print("now at %d clocks, table size is %dX%d" % (players, rows, cols))
+        self.debug("now at %d clocks, table size is %dX%d" % (players, rows, cols))
 
     def switch_clock(self):
         """change the current clock
@@ -487,12 +482,11 @@ much right right side if it *is* present.
         if not self.cur_clock:
             self.cur_clock = self.first_clock
 
-    def status(self, text, priority = 'info'):
-        context_id = self.status_bar.get_context_id(priority)
-        self.maybe_print(text)
-        self.status_bar.push(context_id, text)
+    def status(self, text):
+        self.debug(text)
+        self.turns.set_label(text)
 
-    def maybe_print(self, text):
+    def debug(self, text):
         if self.verbose:
             t = ""
             state = ""
@@ -516,7 +510,7 @@ much right right side if it *is* present.
             p = p.next
             q = q.next
         
-        self.turns.set_label("Turn %d" % self.game.get_turns())
+        self.status("Turn %d" % self.game.get_turns())
         self.hilight()
         
     def refresh_current(self):
@@ -571,7 +565,7 @@ much right right side if it *is* present.
         # notice how we do not handle the arrow keys/home/end/scrlock and num pad
         if event.state & gtk.gdk.CONTROL_MASK or event.state & gtk.gdk.MOD1_MASK:
             # gtk.gdk.SHIFT_MASK is okay
-            self.maybe_print("key pressed with mod/control ignored");
+            self.debug("key pressed with mod/control ignored");
         elif ( keyname == 'Shift_L' or keyname == 'Caps_Lock'
           or keyname == 'Alt_L' or keyname == 'Super_L'
           or event.hardware_keycode == 49 # ~
@@ -600,7 +594,7 @@ much right right side if it *is* present.
         elif keyname == 'Escape':
             if self.fullscreen:
                 self.handle_fullscreen()
-        self.maybe_print("key %s (%d/%d) was pressed" % (keyname, event.keyval, event.hardware_keycode))
+        self.debug("key %s (%d/%d) was pressed" % (keyname, event.keyval, event.hardware_keycode))
 
     def handle_fullscreen(self, action = None):
         if self.fullscreen:
@@ -619,7 +613,6 @@ much right right side if it *is* present.
         """
         # it may be that we need to start the display
         if not self.game.running():
-            self.game.end_turn()
             self.start_game()
         elif not self.first_clock.next:
             self.game.pause()
@@ -634,20 +627,7 @@ much right right side if it *is* present.
         # some reason it doesn't work to just update the old clock label, we need to update both
         self.refresh()
         self.hilight()
-        self.maybe_print("turn finished")
-        # mouse pointer debugging code, see #4511
-        if event and event.device:
-            self.maybe_print("device name: %s" % event.device.name)
-            self.maybe_print("device: %s" % event.device)
-            try:
-                if self.prev_dev == event.device:
-                    self.maybe_print("devices are the same")
-                else:
-                    self.maybe_print("devices are diffrent")
-            except AttributeError:
-                pass
-            self.maybe_print("devices: %s" % gtk.gdk.display_get_default().list_devices())
-            self.prev_dev = event.device.get_source()
+        self.debug("turn finished")
 
     def handle_pause(self, action = None):
         """pause handler
@@ -655,15 +635,15 @@ much right right side if it *is* present.
         just a stub for the game engine for now
         """
         if self.game.pause():
-            self.status("game paused")
+            self.status("turn %d (game paused)" % self.game.get_turns())
         else:
-            self.status("game resumed")
+            self.status("turn %d (game resumed)" % self.game.get_turns())
             # the timeout handler is removed when we pause, resume
             self.timeout_source = gobject.timeout_add(self.loop_timeout, self.refresh_current)
 
     def start_game(self):
+        self.game.switch_clock()
         self.game.start()
         self.timeout_source = gobject.timeout_add(self.loop_timeout, self.refresh_current)
-        self.turns.set_label("Turn %d" % self.game.get_turns())
-        self.maybe_print("refresh rate %dms" % self.loop_timeout)
-        self.status("game started")
+        self.status("Turn %d" % self.game.get_turns())
+        self.debug("refresh rate %dms" % self.loop_timeout)
